==> ondir-0.1.3.tar.gz: ondir-0.1.3/src/Crash.cc <==
#include "Crash.h"
//<module name=drand include=cstdlib>
double drand()
{
	return drand48();
}

void sdrand(unsigned seed)
{
	srand48(seed);
}
//</module>

//<module name=sleep include='unistd.h'>
void sleep(double seconds)
{
	usleep((unsigned long)(seconds * 1000000.0));
}
//</module>

//<module name=time include='sys/time.h,unistd.h'>
double time()
{
struct timeval t;

	return (double)t.tv_sec + (double)t.tv_usec / 1000000.0;
}
//</module>

//<module name=getcwd include='unistd.h'>
string getcwd()
{
char buffer[1024];

	return string(::getcwd(buffer, 1024));
}
//</module>

//<module name=CRC include='cstring'>
static unsigned long crc32_table[256];
/* Initialized first time "crc32()" is called. If you prefer, you can
* statically initialize it at compile time. [Another exercise.]
*/

/*
* Build auxiliary table for parallel byte-at-a-time CRC-32.
*/
#define CRC32_POLY 0x04c11db7     /* AUTODIN II, Ethernet, & FDDI */

static void init_crc32()
{
int i, j;
unsigned long c;

	for (i = 0; i < 256; ++i) {
		for (c = i << 24, j = 8; j > 0; --j)
			c = c & 0x80000000 ? (c << 1) ^ CRC32_POLY : (c << 1);
		crc32_table[i] = c;
	}
}

unsigned long crc(char const *buf, int len)
{
char const *p;
unsigned long crc;

	if (len == -1)
		len = strlen((char const*)buf);
	if (!crc32_table[1])    /* if not already done, */
		init_crc32();   /* build table */
	crc = 0xffffffff;       /* preload shift register, per CRC-32 spec */
	for (p = buf; len > 0; ++p, --len)
		crc = (crc << 8) ^ crc32_table[(crc >> 24) ^ *p];
	return ~crc;            /* transmit complement, per CRC-32 spec */
}
//</module>

==> ondir-0.1.5.tar.gz: ondir-0.1.5/src/Crash.cc <==
#include "Crash.h"
//<module name=drand include=cstdlib>
//double drand()
//{
//	return drand48();
//}
//
//void sdrand(unsigned seed)
//{
//	srand48(seed);
//}
//</module>

//<module name=sleep include='unistd.h'>
void sleep(double seconds)
{
	usleep((unsigned long)(seconds * 1000000.0));
}
//</module>

//<module name=time include='sys/time.h,unistd.h'>
double time()
{
struct timeval t;

	return (double)t.tv_sec + (double)t.tv_usec / 1000000.0;
}
//</module>

//<module name=getcwd include='unistd.h'>
string getcwd()
{
char buffer[1024];

	return string(::getcwd(buffer, 1024));
}
//</module>

//<module name=CRC include='cstring'>
static unsigned long crc32_table[256];
/* Initialized first time "crc32()" is called. If you prefer, you can
* statically initialize it at compile time. [Another exercise.]
*/

/*
* Build auxiliary table for parallel byte-at-a-time CRC-32.
*/
#define CRC32_POLY 0x04c11db7     /* AUTODIN II, Ethernet, & FDDI */

static void init_crc32()
{
int i, j;
unsigned long c;

	for (i = 0; i < 256; ++i) {
		for (c = i << 24, j = 8; j > 0; --j)
			c = c & 0x80000000 ? (c << 1) ^ CRC32_POLY : (c << 1);
		crc32_table[i] = c;
	}
}

unsigned long crc(char const *buf, int len)
{
char const *p;
unsigned long crc;

	if (len == -1)
		len = strlen((char const*)buf);
	if (!crc32_table[1])    /* if not already done, */
		init_crc32();   /* build table */
	crc = 0xffffffff;       /* preload shift register, per CRC-32 spec */
	for (p = buf; len > 0; ++p, --len)
		crc = (crc << 8) ^ crc32_table[(crc >> 24) ^ *p];
	return ~crc;            /* transmit complement, per CRC-32 spec */
}
//</module>
